@@ -212,8 +212,7 @@ private:
 
 LocalNetwork::LocalNetwork()
   : pocbod_(0), tst_redbod_(false), pocmer_(0), tst_redmer_(false),
-    m_0_apr_(10), konf_pr_(0.95), tol_abs_(1000),
-    update_constrained_coordinates_(true), typ_m_0_(empiricka_),
+    m_0_apr_(10), konf_pr_(0.95), tol_abs_(1000), typ_m_0_(empiricka_),
     tst_rov_opr_(false), tst_vyrovnani_(false), min_n_(0), min_x_(nullptr),
     gons_(true)
 {
@@ -242,6 +241,21 @@ LocalNetwork::~LocalNetwork()
 }
 
 
+/* Private member 'AdjInputData input' is defined as an automatic variable,
+ * this can be changed in future versions.
+ *
+ * The following method getAdjInputDat() is designed to mimic situation
+ * where 'input' is declared as a pointer to dynamically allocated object
+ * of type AdjInputData* and getAdjInputData() may return nullptr.
+ */
+const GNU_gama::AdjInputData* LocalNetwork::getAdjInputData() const
+{
+  if (input.mat() == nullptr) return nullptr;
+
+  return &input;
+}
+
+
 double LocalNetwork::cond()
 {
   return least_squares->cond();
@@ -1033,15 +1047,13 @@ void LocalNetwork::refine_approx()
       {
         const PointID& cb = unknown_pointid(i);
         LocalPoint& b = PD[cb];
-        if (!b.constrained_xy() || update_constrained_coordinates())
-            b.set_xy(b.x() + x(i)/1000, b.y() + x(i+1)/1000);
+        b.set_xy(b.x() + x(i)/1000, b.y() + x(i+1)/1000);
       }
     else if (unknown_type(i) == 'Z')
       {
         const PointID& cb = unknown_pointid(i);
         LocalPoint& b = PD[cb];
-        if (!b.constrained_z() || update_constrained_coordinates())
-          b.set_z(b.z() + x(i)/1000);
+        b.set_z(b.z() + x(i)/1000);
       }
     else if (unknown_type(i) == 'R')
       {
@@ -1335,8 +1347,6 @@ std::string LocalNetwork::updated_xml()
   xml += "  tol-abs=\""   + std::to_string(tol_abs())     + "\"\n";
   xml += "  sigma-act=\"";
   xml +=         m_0_apriori() ? "apriori\"\n" : "aposteriori\"\n";
-  xml += "  update-constrained-coordinates=\"";
-  xml +=         update_constrained_coordinates() ? "yes\"\n" : "no\"\n";
   xml += "  angles=\"" + std::string(gons() ? "400" : "360") + "\"\n";
   if (has_algorithm()) xml += "  algorithm=\"" + algorithm() + "\"\n";
   if (has_latitude())
