@@ -342,7 +342,6 @@ namespace GNU_gama { namespace local {
     lnet.conf_pr    (0.95);
     lnet.tol_abs    (1000);
     lnet.set_m_0_aposteriori();
-    lnet.update_constrained_coordinates(true);
 
     state       = state_start;
     standpoint  = 0;
@@ -499,16 +498,6 @@ namespace GNU_gama { namespace local {
             else
               return error(T_GKF_wrong_type_of_standard_deviation);
           }
-        else if (jmeno == "update-constrained-coordinates")
-          {
-            if (hodnota == "yes")
-              lnet.update_constrained_coordinates(true);
-            else if (hodnota == "no" )
-              lnet.update_constrained_coordinates(false);
-            else
-            return error(T_GKF_bad_network_configuration_unknown_parameter
-                         + jmeno + " = " + hodnota);
-          }
         else if (jmeno == "angles")
           {
             if      (hodnota == "400") lnet.set_gons();
