@@ -24,8 +24,9 @@
  */
 
 #include <iostream>
+#include <unordered_set>
 #include <gnu_gama/xml/htmlparser.h>
-
+#include <gnu_gama/gon2deg.h>
 
 using namespace GNU_gama;
 
@@ -84,6 +85,11 @@ int HtmlParser::startElement(const char *name, const char **atts)
   else if (attribute=="adjusted_orientations") adjusted_orientations = true;
   else if (attribute=="adjusted_observations") adjusted_observations = true;
   else if (attribute=="residuals")             residuals             = true;
+  else if (attribute=="angles360")
+    {
+      angles = 360;
+      scale  = 0.324;  // 360*60*60/400/100/100
+    }
 
   if      (tag == "tr")
     {
@@ -480,15 +486,26 @@ void HtmlParser::table_adjusted_orientations()
       return;
     }
 
-  double D;
-  toDouble(data, D);
-
-  if      (table_col == 3) ori.approx = D;
-  else if (table_col == 5) ori.adj    = D;
-  else if (table_col == 6)
+  if (table_col == 3 || table_col == 5)
     {
-      int n = adjres->original_index.size() - 1;
+      double D;
+      if (angles == 400) toDouble(data, D);
+      else               deg2gon( data, D);
+
+      if      (table_col == 3) ori.approx = D;
+      else if (table_col == 5) ori.adj    = D;
+      return;
+    }
+
+  if (table_col == 6)
+    {
+      double D;
+      toDouble(data, D);
+      if (angles == 360) D /= 0.324;  // ss --> cc
+
+      int n = int(adjres->original_index.size() - 1);
       adjres->cov(n,n) = D*D;
+      return;
     }
 }
 
@@ -558,12 +575,24 @@ void HtmlParser::table_adjusted_observations()
 
   LocalNetworkAdjustmentResults::Observation& obs = adjres->obslist.back();
 
+  using unordered_set = std::unordered_set<std::string>;
+  const unordered_set angular {"angle", "azimuth", "direction", "zenith-angle"};
+  bool obsang = (angular.find(obs.xml_tag) != angular.end());
+
   double D;
-  toDouble(data, D);
+  if (obsang)
+    {
+      if (angles == 400) toDouble(data, D);
+      else               deg2gon( data, D);
+    }
+  else
+    {
+      toDouble(data, D);
+    }
 
   if      (table_col == 5) obs.obs   = D;
   else if (table_col == 6) obs.adj   = D;
-  else if (table_col == 7) obs.stdev = D;
+  else if (table_col == 7) obs.stdev = obsang ? D*0.324 : D;
 }
 
 
