@@ -79,7 +79,7 @@ int b02()
     }
   catch (const Exception::matvec& e)
     {
-      cout << e.description << endl;
+      cout << e.what() << endl;
       return 1;
     }
 
